@@ -3,7 +3,7 @@ Functions for reading from the PVSite database
 """
 
 from .generation import get_pv_generation_by_client, get_pv_generation_by_sites
-from .latest_forecast_values import get_latest_forecast_values_by_site
+from .latest_forecast_values import get_latest_forecast_values_by_site, get_forecast_values_by_site_latest
 from .site import (
     get_all_sites,
     get_site_by_client_site_id,
