@@ -1,21 +1,19 @@
-"""
-Functions to read from the Status table
-"""
+"""Functions to read from the Status table."""
 
 from typing import Optional
 
-from pvsite_datamodel.sqlmodels import StatusSQL
 from sqlalchemy.orm import Session
 
+from pvsite_datamodel.sqlmodels import StatusSQL
+
 
 def get_latest_status(session: Session) -> Optional[StatusSQL]:
-    """
-    Gets the latest entry in the status table. Returns None if there are no entries
+    """Get the latest entry in the status table.
 
+    Return None if there are no entries.
     :param session: database session
-    return: Latest StatusSQL object, or None
+    :return: Latest StatusSQL object, or None
     """
-
     # Query status table, ordered by created time
     query = session.query(StatusSQL)
     query = query.order_by(StatusSQL.created_utc.desc())
