@@ -1,17 +1,15 @@
-"""
-Generic DB rows writer
-"""
+"""Generic DB rows writer."""
 
 import sqlalchemy as sa
-from pvsite_datamodel.sqlmodels import Base
-from pvsite_datamodel.write.utils import WrittenRow
 from sqlalchemy import orm as sa_orm
 from sqlalchemy.dialects import postgresql as sa_psql
 
+from pvsite_datamodel.sqlmodels import Base
+from pvsite_datamodel.write.utils import WrittenRow
+
 
 def upsert(session: sa_orm.Session, table: Base, rows: list[dict]) -> list[WrittenRow]:
-    """
-    Upsert rows into table
+    """Upserts rows into table.
 
     This functions checks the primary keys, and if present, updates the row.
     :param session: sqlalchemy Session
@@ -21,7 +19,6 @@ def upsert(session: sa_orm.Session, table: Base, rows: list[dict]) -> list[Writt
     key values
     that have been written
     """
-
     # Input type validation in case user passes in a dict, not a list of dicts
     if type(rows) != list:
         if type(rows) == dict:
