@@ -1,6 +1,4 @@
-"""
-Cross-package functions
-"""
+"""Cross-package functions."""
 
 import datetime as dt
 import typing
@@ -9,9 +7,7 @@ from pvsite_datamodel.sqlmodels import Base
 
 
 class WrittenRow(typing.NamedTuple):
-    """
-    Defines a write to the Database
-    """
+    """Defines a write to the Database."""
 
     table: Base
     pk_value: str
